sympy: Python library for symbolic mathematics
==============================================

Description
-----------

SymPy is a Python library for symbolic mathematics. It aims to become a
full-featured computer algebra system (CAS) while keeping the code as
simple as possible in order to be comprehensible and easily extensible.
SymPy is written entirely in Python and does not require any external
libraries, except optionally for plotting support.

Website
-------

https://sympy.org/

License
-------

New BSD: http://www.opensource.org/licenses/bsd-license.php


Upstream Contact
----------------

https://pypi.org/project/sympy/

